[![CircleCI](https://circleci.com/gh/chrishannam/hippocrates/tree/master.svg?style=svg)](https://circleci.com/gh/chrishannam/hippocrates/tree/master)

# Hippocrates
A Python library for giving and scoring various health based questionnaires.

# Supported Questionnaires
Below are the supported currently.

## [Beck Depression Inventory](https://en.wikipedia.org/wiki/Beck_Depression_Inventory)
The Beck Depression Inventory (BDI, BDI-1A, BDI-II), created by Aaron T. Beck,
is a 21-question multiple-choice self-report inventory, one of the most widely
used psychometric tests for measuring the severity of depression. Its
development marked a shift among mental health professionals, who had
until then, viewed depression from a psychodynamic perspective, instead of it
being rooted in the patient's own thoughts.

## [Generalized Anxiety Disorder 2](https://en.wikipedia.org/wiki/Generalized_anxiety_disorder)
Generalized anxiety disorder (GAD) is an anxiety disorder characterized by
excessive, uncontrollable and often irrational worry, that is, apprehensive
expectation about events or activities. This excessive worry often interferes
with daily functioning, as individuals with GAD typically anticipate disaster,
 and are overly concerned about everyday matters such as health issues, money,
 death, family problems, friendship problems, interpersonal relationship problems,
 or work difficulties.

## [Generalized Anxiety Disorder 7](https://en.wikipedia.org/wiki/Generalized_Anxiety_Disorder_7)
Generalized Anxiety Disorder 7 (GAD-7) is a self-reported questionnaire for
screening and severity measuring of generalized anxiety disorder (GAD).
GAD-7 has seven items, which measure severity of various signs of GAD according
to reported response categories with assigned points (see below). Assessment is
indicated by the total score, which made up by adding together the scores for
the scale all seven items.

## [Patient Health Questionnaire 2](https://en.wikipedia.org/wiki/Patient_Health_Questionnaire#2-item_depression_screener)
The Patient Health Questionnaire 2 item (PHQ-2) is an ultra-brief screening
instrument containing the first two questions from the PHQ-9. Two screening
questions to assess the presence of a depressed mood and a loss of interest
or pleasure in routine activities, and a positive response to either question
indicates further testing is required. This version of the PHQ has been shown
to have good diagnostic sensitivity but poor specificity.


## [Patient Health Questionnaire 7](https://en.wikipedia.org/wiki/PHQ-9)
The PHQ-9 is a 9-question instrument given to patients in a primary care
setting to screen for the presence and severity of depression. It is the
9-question depression scale from the Patient Health Questionnaire (PHQ).
The results of the PHQ-9 may be used to make a depression diagnosis according
to DSM-IV criteria and takes less than 3 minutes to complete. The total of all
 9 responses from the PHQ-9 aims to predict the presence and severity of
 depression. Primary care providers frequently use the PHQ-9 to screen for
 depression in patients.

## [Rosenberg Self-Esteem Scale](https://en.wikipedia.org/wiki/Rosenberg_self-esteem_scale)
The Rosenberg self-esteem scale (RSES), developed by sociologist Dr. Morris
Rosenberg, is a self-esteem measure widely used in social-science research.
It uses a scale of 0-30 where a score less than 15 may indicate a problematic
low self esteem.

# Links
https://www.mdcalc.com/phq-9-patient-health-questionnaire-9
